#pragma once

#include "Shader.h"

/**
 * @brief 
 * Abstract base class called `Renderable`. It has a pure virtual function
 * called `render` that takes a reference to a `Shader` object as a parameter.
 * This means that any class that inherits from `Renderable` must implement
 * the `render` function. The `render` function is responsible for rendering
 * the object using the provided `Shader`.
 */
class Renderable
{
public:
    /**
     * @brief Render the given object via the given shader.
     * 
     * @param shader The vertex and fragment shader program to use for
     * rendering.
     */
    virtual void render( Shader &shader ) = 0;
};